@@ -6,21 +6,24 @@
 # Dic 21, 2009
 
 import os
-import gtk
 
-class About:
+from gi.repository import Gtk
+
+from turpial import NAME
+from turpial import VERSION
+from turpial.ui.lang import i18n
+
+class AboutDialog(Gtk.AboutDialog):
     def __init__(self, parent=None):
-        about = gtk.AboutDialog()
-        about.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
-        about.set_logo(parent.load_image('turpial.png', True))
-        about.set_name('Turpial')
-        about.set_version(parent.version)
-        about.set_copyright('Copyright (C) 2009 - 2011 Wil Alvarez')
-        about.set_comments(_('Microblogging client written in Python'))
-        about.set_transient_for(parent)
-        about.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
-        about.set_website('http://turpial.org.ve')
-        
+        Gtk.AboutDialog.__init__(self)
+        self.set_logo(parent.load_image('turpial.png', True))
+        self.set_name(NAME)
+        self.set_version(VERSION)
+        self.set_modal(True)
+        self.set_copyright('Copyright (C) 2009 - 2012 Wil Alvarez')
+        self.set_comments(i18n.get('about_description'))
+        self.set_website('http://turpial.org.ve')
+
         try:
             path = os.path.realpath(os.path.join(os.path.dirname(__file__), 
                 '..', '..', '..', 'COPYING'))
@@ -36,7 +39,7 @@ class About:
             license += 'License along with\nthis script (see license); if not, write to '
             license += 'the Free Software\nFoundation, Inc., 59 Temple Place, Suite 330, '
             license += 'Boston, MA  02111-1307  USA'
-        about.set_license(license)
+        self.set_license(license)
         authors = []
         try:
             path = os.path.realpath(os.path.join(os.path.dirname(__file__), 
@@ -46,31 +49,22 @@ class About:
                 authors.append(line.strip('\n'))
             f.close()
         except Exception, msg:
-            authors = [_("File 'AUTHORS' not found")]
-        about.set_authors(authors)
-        
-        translators = ''
-        try:
-            path = os.path.realpath(os.path.join(os.path.dirname(__file__), 
-                '..', '..', '..', 'TRANSLATORS'))
-            f = file(path, 'r')
-            translators = f.read()
-            f.close()
-        except Exception, msg:
-            translators = _("File 'TRANSLATORS' not found")
-        about.set_translator_credits(translators)
-        
-        about.connect("response", self.__response)
-        about.connect("close", self.__close)
-        about.connect("delete_event", self.__close)
-        
-        about.run()
-        
+            authors = [i18n.get('file_not_found')]
+        self.set_authors(authors)
+
+        self.connect("response", self.__response)
+        self.connect("close", self.__close)
+        self.connect("delete_event", self.__close)
+
+
     def __response(self, dialog, response, *args):
         if response < 0:
             dialog.destroy()
             dialog.emit_stop_by_name('response')
-        
+
     def __close(self, widget, event=None):
-        widget.destroy()
+        self.destroy()
         return True
+
+    def quit(self):
+        self.destroy()
